import { Component, OnInit, ViewChild } from '@angular/core';
import { MatButton } from '@angular/material/button';
import { MatTableDataSource } from '@angular/material/table';
import { ActivatedRoute, Router } from '@angular/router';
import { ContractService } from '../data-object-service';
import { Contract, NULL_CommercialPremise, NULL_Contract } from '../data-objects';
import { MessageService } from '../message.service';

@Component({
  selector: 'app-contract',
  templateUrl: './contract.component.html',
  styleUrls: ['./contract.component.css']
})
export class ContractComponent implements OnInit {

  @ViewChild('submitButton') submitButton: MatButton

  contract: Contract = NULL_Contract
  
  constructor(
    private contractService: ContractService, 
    private messageService: MessageService,
    private route: ActivatedRoute,
    private router: Router
  ) { }

  async getContract(): Promise<void> {
    try {
      const id = +this.route.snapshot.paramMap.get('id')
      if (id != 0) {
        this.contract = await this.contractService.getContract(id)
      }
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  async saveContract() {
    try {
      this.submitButton.disabled = true
      this.messageService.add(`saveContract: ${ JSON.stringify(this.contract, undefined, 4) }`)
      if (this.contract.id == 0) {
        this.messageService.add("about to insert new contract")
        this.contract = await this.contractService.postContract(this.contract)
        this.messageService.add(`Successfully added contract with id ${this.contract.id}`)
      } else {
        this.messageService.add("about to update existing contract")
        this.contract = await this.contractService.putContract(this.contract)
        this.messageService.add(`Successfully changed contract with id ${this.contract.id}`)
      }
      this.router.navigate(['/contracts'])
    } finally {
      this.submitButton.disabled = false
    }
  }

  ngOnInit(): void {
    this.getContract()
  }

}
