import { Component, OnInit } from '@angular/core';
import { MatTableDataSource } from '@angular/material/table';
import { ContractService } from '../data-object-service';
import { Contract } from '../data-objects';
import { MessageService } from '../message.service';

@Component({
  selector: 'app-my-contracts',
  templateUrl: './my-contracts.component.html',
  styleUrls: ['./my-contracts.component.css']
})
export class MyContractsComponent implements OnInit {

  contracts: Contract[]
  dataSource: MatTableDataSource<Contract>
  displayedColumns: string[] = [ "supplier", "content", "identifier" ]
  
  constructor(private contractService: ContractService, private messageService: MessageService) { }

  async getContracts(): Promise<void> {
    try {
      this.messageService.add("Trying to load contracts")
      this.contracts = await this.contractService.getContracts();
      this.messageService.add("Contracts loaded")

      this.dataSource = new MatTableDataSource<Contract>(this.contracts)
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  ngOnInit(): void {
    this.messageService.add("MyContractsComponent.ngOnInit")
    this.getContracts()
  }


}
